==> estateplat-common-1.1.0-20170321.034124-276-sources.jar: cn/gtmap/estateplat/model/server/core/DjsjFwxx.java <==
package cn.gtmap.estateplat.model.server.core;

import java.util.Date;
import java.util.List;

/**
 * 房屋信息实体类 房屋结构和竣工时间在子表中
 * Created by lst on 2015/3/12.
 */
public class DjsjFwxx {
    private String id;
    private String fwDcbIndex;
    private String gyqk;
    private String tdsyqr;
    private Double dytdmj;
    private Double fttdmj;
    private Double jyjg;
    private String ghyt;
    private String fwxz;
    private String dycs;
    private Integer wlcs;
    private Integer zcs;
    private Double tnjzmj;
    private Double ftjzmj;
    private Double cg;
    private String qlr;
    private String qlrzjlx;
    private String qlrzjh;
    private Integer dwxz;
    private String dh;
    private Integer fwcs;
    private String fwyt;
    private Double jzmj;
    private Integer zts;
    private String bdcdyh;
    private String zl;
    private String xmjc;
    private String lszd;
    private String zrddh;
    private String fcdah;        //  房屋档案号
    private String cqly;         //     产权来源
    private String bdcdyfwlx;
    private String fwlx;
    private String gyfs;
    private Double ycjzmj;       //预测建筑面积
    List<DjsjFwzbxx> fwzbxxList;
    private String yb;//权利人邮编
    private String dz;//权利人通讯地址
    private String fcghyt;//房产规划用途


    private String tdyt;//权籍里面增加的tdyt

    private Date qsrq;//权籍里面针对tdyt的日期
    private Date zzrq;//权籍里面针对tdyt的日期

    private String tdsyqlx;//土地使用权类型

    public String getTdsyqlx() {
        return tdsyqlx;
    }

    public void setTdsyqlx(String tdsyqlx) {
        this.tdsyqlx = tdsyqlx;
    }

    public String getTdyt() {
        return tdyt;
    }

    public void setTdyt(String tdyt) {
        this.tdyt = tdyt;
    }

    public Date getQsrq() {
        return qsrq;
    }

    public void setQsrq(Date qsrq) {
        this.qsrq = qsrq;
    }

    public Date getZzrq() {
        return zzrq;
    }

    public void setZzrq(Date zzrq) {
        this.zzrq = zzrq;
    }

    public String getFcghyt() {
        return fcghyt;
    }

    public void setFcghyt(String fcghyt) {
        this.fcghyt = fcghyt;
    }

    public String getYb() {
        return yb;
    }

    public void setYb(String yb) {
        this.yb = yb;
    }

    public String getDz() {
        return dz;
    }

    public void setDz(String dz) {
        this.dz = dz;
    }

    public String getId() {
        return id;
    }

    public void setId(String id) {
        this.id = id;
    }

    public String getBdcdyh() {
        return bdcdyh;
    }

    public void setBdcdyh(String bdcdyh) {
        this.bdcdyh = bdcdyh;
    }

    public String getZl() {
        return zl;
    }

    public void setZl(String zl) {
        this.zl = zl;
    }

    public String getFwDcbIndex() {
        return fwDcbIndex;
    }

    public void setFwDcbIndex(String fwDcbIndex) {
        this.fwDcbIndex = fwDcbIndex;
    }

    public String getGyqk() {
        return gyqk;
    }

    public void setGyqk(String gyqk) {
        this.gyqk = gyqk;
    }

    public String getTdsyqr() {
        return tdsyqr;
    }

    public void setTdsyqr(String tdsyqr) {
        this.tdsyqr = tdsyqr;
    }

    public Double getDytdmj() {
        return dytdmj;
    }

    public void setDytdmj(Double dytdmj) {
        this.dytdmj = dytdmj;
    }

    public Double getFttdmj() {
        return fttdmj;
    }

    public void setFttdmj(Double fttdmj) {
        this.fttdmj = fttdmj;
    }

    public Double getJyjg() {
        return jyjg;
    }

    public void setJyjg(Double jyjg) {
        this.jyjg = jyjg;
    }

    public String getGhyt() {
        return ghyt;
    }

    public void setGhyt(String ghyt) {
        this.ghyt = ghyt;
    }

    public String getFwxz() {
        return fwxz;
    }

    public void setFwxz(String fwxz) {
        this.fwxz = fwxz;
    }

    public String getDycs() {
        return dycs;
    }

    public void setDycs(String dycs) {
        this.dycs = dycs;
    }

    public Integer getZcs() {
        return zcs;
    }

    public void setZcs(Integer zcs) {
        this.zcs = zcs;
    }

    public Double getTnjzmj() {
        return tnjzmj;
    }

    public void setTnjzmj(Double tnjzmj) {
        this.tnjzmj = tnjzmj;
    }

    public Double getFtjzmj() {
        return ftjzmj;
    }

    public void setFtjzmj(Double ftjzmj) {
        this.ftjzmj = ftjzmj;
    }


    public Double getCg() {
        return cg;
    }

    public void setCg(Double cg) {
        this.cg = cg;
    }

    public String getQlr() {
        return qlr;
    }

    public void setQlr(String qlr) {
        this.qlr = qlr;
    }

    public String getQlrzjlx() {
        return qlrzjlx;
    }

    public void setQlrzjlx(String qlrzjlx) {
        this.qlrzjlx = qlrzjlx;
    }

    public String getQlrzjh() {
        return qlrzjh;
    }

    public void setQlrzjh(String qlrzjh) {
        this.qlrzjh = qlrzjh;
    }

    public Integer getDwxz() {
        return dwxz;
    }

    public void setDwxz(Integer dwxz) {
        this.dwxz = dwxz;
    }

    public String getDh() {
        return dh;
    }

    public void setDh(String dh) {
        this.dh = dh;
    }

    public Integer getFwcs() {
        return fwcs;
    }

    public void setFwcs(Integer fwcs) {
        this.fwcs = fwcs;
    }

    public String getFwyt() {
        return fwyt;
    }

    public void setFwyt(String fwyt) {
        this.fwyt = fwyt;
    }


    public Double getJzmj() {
        return jzmj;
    }

    public void setJzmj(Double jzmj) {
        this.jzmj = jzmj;
    }

    public Integer getZts() {
        return zts;
    }

    public void setZts(Integer zts) {
        this.zts = zts;
    }

    public String getXmjc() {
        return xmjc;
    }

    public void setXmjc(String xmjc) {
        this.xmjc = xmjc;
    }

    public String getLszd() {
        return lszd;
    }

    public void setLszd(String lszd) {
        this.lszd = lszd;
    }

    public String getZrddh() {
        return zrddh;
    }

    public void setZrddh(String zrddh) {
        this.zrddh = zrddh;
    }

    public String getFcdah() {
        return fcdah;
    }

    public void setFcdah(String fcdah) {
        this.fcdah = fcdah;
    }

    public String getCqly() {
        return cqly;
    }

    public void setCqly(String cqly) {
        this.cqly = cqly;
    }

    public String getBdcdyfwlx() {
        return bdcdyfwlx;
    }

    public void setBdcdyfwlx(String bdcdyfwlx) {
        this.bdcdyfwlx = bdcdyfwlx;
    }


    public List<DjsjFwzbxx> getFwzbxxList() {
        return fwzbxxList;
    }

    public void setFwzbxxList(List<DjsjFwzbxx> fwzbxxList) {
        this.fwzbxxList = fwzbxxList;
    }

    public String getFwlx() {
        return fwlx;
    }

    public void setFwlx(String fwlx) {
        this.fwlx = fwlx;
    }

    public String getGyfs() {
        return gyfs;
    }

    public void setGyfs(String gyfs) {
        this.gyfs = gyfs;
    }

    public Double getYcjzmj() {
        return ycjzmj;
    }

    public void setYcjzmj(Double ycjzmj) {
        this.ycjzmj = ycjzmj;
    }

    public Integer getWlcs() {
        return wlcs;
    }

    public void setWlcs(Integer wlcs) {
        this.wlcs = wlcs;
    }
}

==> estateplat-common-1.2.3-20180110.011455-11-sources.jar: cn/gtmap/estateplat/model/server/core/DjsjFwxx.java <==
package cn.gtmap.estateplat.model.server.core;

import java.util.Date;
import java.util.List;

/**
 * 房屋信息实体类 房屋结构和竣工时间在子表中
 * Created by lst on 2015/3/12.
 */
public class DjsjFwxx {
    private String id;
    private String fwDcbIndex;
    private String gyqk;
    private String tdsyqr;
    private Double dytdmj;
    private Double fttdmj;
    private Double jyjg;
    private String ghyt;
    private String fwxz;
    private String dycs;
    private Integer wlcs;
    private Integer zcs;
    private Double tnjzmj;
    private Double ftjzmj;
    private Double cg;
    private String qlr;
    private String qlrzjlx;
    private String qlrzjh;
    private Integer dwxz;
    private String dh;
    private Integer fwcs;
    private String fwyt;
    private Double jzmj;
    private Integer zts;
    private String bdcdyh;
    private String zl;
    private String xmjc;
    private String lszd;
    private String zrddh;
    private String fcdah;        //  房屋档案号
    private String cqly;         //     产权来源
    private String bdcdyfwlx;
    private String fwlx;
    private String gyfs;
    private Double ycjzmj;       //预测建筑面积
    List<DjsjFwzbxx> fwzbxxList;
    private String yb;//权利人邮编
    private String dz;//权利人通讯地址
    private String fcghyt;//房产规划用途


    private String tdyt;//权籍里面增加的tdyt

    private Date qsrq;//权籍里面针对tdyt的日期
    private Date zzrq;//权籍里面针对tdyt的日期

    private String tdsyqlx;//土地使用权类型
    private Double zzdmj;

    public String getTdsyqlx() {
        return tdsyqlx;
    }

    public void setTdsyqlx(String tdsyqlx) {
        this.tdsyqlx = tdsyqlx;
    }

    public String getTdyt() {
        return tdyt;
    }

    public void setTdyt(String tdyt) {
        this.tdyt = tdyt;
    }

    public Date getQsrq() {
        return qsrq;
    }

    public void setQsrq(Date qsrq) {
        this.qsrq = qsrq;
    }

    public Date getZzrq() {
        return zzrq;
    }

    public void setZzrq(Date zzrq) {
        this.zzrq = zzrq;
    }

    public String getFcghyt() {
        return fcghyt;
    }

    public void setFcghyt(String fcghyt) {
        this.fcghyt = fcghyt;
    }

    public String getYb() {
        return yb;
    }

    public void setYb(String yb) {
        this.yb = yb;
    }

    public String getDz() {
        return dz;
    }

    public void setDz(String dz) {
        this.dz = dz;
    }

    public String getId() {
        return id;
    }

    public void setId(String id) {
        this.id = id;
    }

    public String getBdcdyh() {
        return bdcdyh;
    }

    public void setBdcdyh(String bdcdyh) {
        this.bdcdyh = bdcdyh;
    }

    public String getZl() {
        return zl;
    }

    public void setZl(String zl) {
        this.zl = zl;
    }

    public String getFwDcbIndex() {
        return fwDcbIndex;
    }

    public void setFwDcbIndex(String fwDcbIndex) {
        this.fwDcbIndex = fwDcbIndex;
    }

    public String getGyqk() {
        return gyqk;
    }

    public void setGyqk(String gyqk) {
        this.gyqk = gyqk;
    }

    public String getTdsyqr() {
        return tdsyqr;
    }

    public void setTdsyqr(String tdsyqr) {
        this.tdsyqr = tdsyqr;
    }

    public Double getDytdmj() {
        return dytdmj;
    }

    public void setDytdmj(Double dytdmj) {
        this.dytdmj = dytdmj;
    }

    public Double getFttdmj() {
        return fttdmj;
    }

    public void setFttdmj(Double fttdmj) {
        this.fttdmj = fttdmj;
    }

    public Double getJyjg() {
        return jyjg;
    }

    public void setJyjg(Double jyjg) {
        this.jyjg = jyjg;
    }

    public String getGhyt() {
        return ghyt;
    }

    public void setGhyt(String ghyt) {
        this.ghyt = ghyt;
    }

    public String getFwxz() {
        return fwxz;
    }

    public void setFwxz(String fwxz) {
        this.fwxz = fwxz;
    }

    public String getDycs() {
        return dycs;
    }

    public void setDycs(String dycs) {
        this.dycs = dycs;
    }

    public Integer getZcs() {
        return zcs;
    }

    public void setZcs(Integer zcs) {
        this.zcs = zcs;
    }

    public Double getTnjzmj() {
        return tnjzmj;
    }

    public void setTnjzmj(Double tnjzmj) {
        this.tnjzmj = tnjzmj;
    }

    public Double getFtjzmj() {
        return ftjzmj;
    }

    public void setFtjzmj(Double ftjzmj) {
        this.ftjzmj = ftjzmj;
    }


    public Double getCg() {
        return cg;
    }

    public void setCg(Double cg) {
        this.cg = cg;
    }

    public String getQlr() {
        return qlr;
    }

    public void setQlr(String qlr) {
        this.qlr = qlr;
    }

    public String getQlrzjlx() {
        return qlrzjlx;
    }

    public void setQlrzjlx(String qlrzjlx) {
        this.qlrzjlx = qlrzjlx;
    }

    public String getQlrzjh() {
        return qlrzjh;
    }

    public void setQlrzjh(String qlrzjh) {
        this.qlrzjh = qlrzjh;
    }

    public Integer getDwxz() {
        return dwxz;
    }

    public void setDwxz(Integer dwxz) {
        this.dwxz = dwxz;
    }

    public String getDh() {
        return dh;
    }

    public void setDh(String dh) {
        this.dh = dh;
    }

    public Integer getFwcs() {
        return fwcs;
    }

    public void setFwcs(Integer fwcs) {
        this.fwcs = fwcs;
    }

    public String getFwyt() {
        return fwyt;
    }

    public void setFwyt(String fwyt) {
        this.fwyt = fwyt;
    }


    public Double getJzmj() {
        return jzmj;
    }

    public void setJzmj(Double jzmj) {
        this.jzmj = jzmj;
    }

    public Integer getZts() {
        return zts;
    }

    public void setZts(Integer zts) {
        this.zts = zts;
    }

    public String getXmjc() {
        return xmjc;
    }

    public void setXmjc(String xmjc) {
        this.xmjc = xmjc;
    }

    public String getLszd() {
        return lszd;
    }

    public void setLszd(String lszd) {
        this.lszd = lszd;
    }

    public String getZrddh() {
        return zrddh;
    }

    public void setZrddh(String zrddh) {
        this.zrddh = zrddh;
    }

    public String getFcdah() {
        return fcdah;
    }

    public void setFcdah(String fcdah) {
        this.fcdah = fcdah;
    }

    public String getCqly() {
        return cqly;
    }

    public void setCqly(String cqly) {
        this.cqly = cqly;
    }

    public String getBdcdyfwlx() {
        return bdcdyfwlx;
    }

    public void setBdcdyfwlx(String bdcdyfwlx) {
        this.bdcdyfwlx = bdcdyfwlx;
    }


    public List<DjsjFwzbxx> getFwzbxxList() {
        return fwzbxxList;
    }

    public void setFwzbxxList(List<DjsjFwzbxx> fwzbxxList) {
        this.fwzbxxList = fwzbxxList;
    }

    public String getFwlx() {
        return fwlx;
    }

    public void setFwlx(String fwlx) {
        this.fwlx = fwlx;
    }

    public String getGyfs() {
        return gyfs;
    }

    public void setGyfs(String gyfs) {
        this.gyfs = gyfs;
    }

    public Double getYcjzmj() {
        return ycjzmj;
    }

    public void setYcjzmj(Double ycjzmj) {
        this.ycjzmj = ycjzmj;
    }

    public Integer getWlcs() {
        return wlcs;
    }

    public void setWlcs(Integer wlcs) {
        this.wlcs = wlcs;
    }

    public Double getZzdmj() {
        return zzdmj;
    }

    public void setZzdmj(Double zzdmj) {
        this.zzdmj = zzdmj;
    }
}
